# frozen_string_literal: true

Application.boot(:karafka) do
  init do
    require "karafka"
    require "kafka/datadog"
    require "cht-lib-fabric/helpers/topic_mapper"
  end

  # Using custom settings for session timeout and max bytes to avoid a timeout when checking in messages offsets after
  # processing a batch of messages.
  # See: https://cloudhealthtech.atlassian.net/browse/AWS-12087
  start do
    ::Karafka::App.setup do |kc|
      kc.kafka.seed_brokers = ["kafka://#{target["settings"].kafka_host}"]
      kc.kafka.session_timeout = 90
      # this setting will allow about 500-600 messages per batch (~300 bytes/msg)
      kc.kafka.max_bytes_per_partition = 200000
      kc.client_id = "#{SERVICE_NAME}-#{SERVICE_TASK}"
      kc.backend = :inline
      kc.logger.level = Logger::WARN
      WaterDrop.logger = kc.logger
    end

    ::Kafka::Datadog.statsd = target["statsd"]
  end
end
