# frozen_string_literal: true

Application.boot(:sidekiq) do
  init do
    require "sidekiq"
    require "sidekiq_unique_jobs"
    require "job_management"
    require "containers_cp/processing/reject_strategy"
  end

  start do
    redis_host = target[:settings].sidekiq_redis_host
    redis_port = target[:settings].sidekiq_redis_port

    SSL_ENVS = %w(production staging)
    # rediss:// is not a typo.
    # Enables SSL connection within `redis` gem.
    redis_uri_scheme = SSL_ENVS.include?(ENV['RACK_ENV']) && ENV["DEPLOYMENT_PROVIDER"].downcase == "aws" ? 'rediss://' : 'redis://'
    redis_url = "#{redis_uri_scheme}#{redis_host}:#{redis_port}"

    logger = target[:logger]
    logger.info "Sidekiq redis URL: #{redis_url}"

    Sidekiq.configure_server do |config|
      config.logger.level = Logger::ERROR
      config.redis = {url: redis_url, reconnect_attempts: 25, db: 1}

      config.client_middleware do |chain|
        chain.add SidekiqUniqueJobs::Middleware::Client
      end

      config.server_middleware do |chain|
        chain.add SidekiqUniqueJobs::Middleware::Server
      end

      SidekiqUniqueJobs::Server.configure(config)
      SidekiqUniqueJobs.config.lock_info = true
    end

    Sidekiq.configure_client do |config|
      config.logger.level = Logger::ERROR
      config.redis = {url: redis_url, reconnect_attempts: 25, db: 1}

      config.client_middleware do |chain|
        chain.add SidekiqUniqueJobs::Middleware::Client
      end
      SidekiqUniqueJobs.config.lock_info = true
    end

    SidekiqUniqueJobs.configure do |config|
      config.add_strategy :custom_reject_strategy, ::ContainersCp::Processing::RejectStrategy
    end
  end
end
